@@ -4,11 +4,11 @@ import os
 from typing import Any, Optional
 
 import requests
-from basicauth import decode
 from requests.adapters import HTTPAdapter
 from requests_file import FileAdapter
 from urllib3.util import Retry
 
+from .encoding import basicauth_decode
 from .loader import load_json, load_text, load_yaml
 from .useragent import UserAgent
 
@@ -156,7 +156,7 @@ def get_session(
         )
     if "headers" not in auths_found:
         if basic_auth:
-            auth = decode(basic_auth)
+            auth = basicauth_decode(basic_auth)
         s.auth = auth
 
     status_forcelist = kwargs.get(
